const inititateTabs = () => {
    // Get relevant elements and collections
    const tablist = document.querySelector('.js-tabs');
    const tabs = tablist.querySelectorAll('.js-tab');
    const panels = document.querySelectorAll('.js-tabs-content');

    const updateHash = (hash) => {
        if (!hash) {
            return;
        }

        window.location.hash = hash;

        if (history.pushState) {
            history.pushState(null, hash);
        } else {
            location.hash = hash;
        }
    };

    // The tab switching function
    const switchTab = (oldTab, newTab) => {
        newTab.focus();
        // Make the active tab focusable by the user (Tab key)
        newTab.removeAttribute('tabindex');
        // Set the selected state
        newTab.setAttribute('aria-selected', 'true');
        oldTab.removeAttribute('aria-selected');
        oldTab.setAttribute('tabindex', '-1');
        // Get the indices of the new and old tabs to find the correct
        // tab panels to show and hide
        const index = Array.prototype.indexOf.call(tabs, newTab);
        const oldIndex = Array.prototype.indexOf.call(tabs, oldTab);
        panels[oldIndex].hidden = true;
        panels[index].hidden = false;
    };

    // Add the tablist role to the first <ul> in the .tabbed container
    tablist.setAttribute('role', 'tablist');

    // Add semantics are remove user focusability for each tab
    Array.prototype.forEach.call(tabs, (tab, i) => {
        tab.setAttribute('role', 'tab');
        tab.setAttribute('id', 'tab' + (i + 1));
        tab.setAttribute('tabindex', '-1');
        tab.parentNode.setAttribute('role', 'presentation');

        // Handle clicking of tabs for mouse users
        tab.addEventListener('click', e => {
            e.preventDefault();
            const currentTab = tablist.querySelector('[aria-selected]');
            if (e.currentTarget !== currentTab) {
                updateHash(e.currentTarget.dataset.hash);
                switchTab(currentTab, e.currentTarget);
            }
        });

        // Handle keydown events for keyboard users
        tab.addEventListener('keydown', e => {
        // Get the index of the current tab in the tabs node list
            const index = Array.prototype.indexOf.call(tabs, e.currentTarget);
            // Work out which key the user is pressing and
            // Calculate the new tab's index where appropriate
            const dir = e.which === 37 ? index - 1 : e.which === 39 ? index + 1 : e.which === 40 ? 'down' : null;
            if (dir !== null) {
                e.preventDefault();
                // If the down key is pressed, move focus to the open panel,
                // otherwise switch to the adjacent tab
                if (dir === 'down') {
                    panels[i].focus();
                } else if (tabs[dir]) {
                    updateHash(e.currentTarget.dataset.hash);
                    switchTab(e.currentTarget, tabs[dir]);
                }
            }
        });
    });

    // Add tab panel semantics and hide them all
    Array.prototype.forEach.call(panels, (panel, i) => {
        panel.setAttribute('role', 'tabpanel');
        panel.setAttribute('tabindex', '-1');
        panel.setAttribute('aria-labelledby', tabs[i].id);
        panel.hidden = true;
    });

    let indx = 0;
    if (location.hash) {
        const ID = location.hash.replace('#', '');
        panels.forEach((panel, i) => {
            if (panel.id === ID) {
                indx = i;
            }
        });
    }

    // Initially activate the first tab and reveal the first tab panel
    tabs[indx].removeAttribute('tabindex');
    tabs[indx].setAttribute('aria-selected', 'true');
    panels[indx].hidden = false;
};

export default inititateTabs;
